BOLLStyle class

Inheritance

Constructors

BOLLStyle({Color bollColor = const Color(0xFFF7931A), Color ubColor = const Color(0xFFFFC634), Color lbColor = const Color(0xFFFFC634), Color fillColor = const Color(0x12FFC634)})
const

Properties

bollColor → Color
final
fillColor → Color
final
hashCode → int
The hash code for this object.
no setterinherited
lbColor → Color
final
lineWidth → double
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strokeWidth → double
finalinherited
ubColor → Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited