Boll class

Constructors

Boll()

Properties

BOLLMA ↔ double?
getter/setter pair
dn ↔ double?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mid ↔ double?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
up ↔ double?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited