CCIIndicator class

Inheritance

Constructors

CCIIndicator({CCIStyle indicatorStyle = const CCIStyle()})

Properties

calcParams → List<int>
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
indicatorStyle → CCIStyle
finalinherited
name → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortName → String
finalinherited

Methods

calc(List<KLineEntity> dataList) → void
override
drawChart(MACDEntity lastPoint, MACDEntity curPoint, double lastX, double curX, GetYFunction getY, Canvas canvas, KChartColors chartColors) → void
override
drawFigure(MACDEntity entity, int precision, KChartColors chartColors) → TextSpan?
override
drawVerticalText({required Canvas canvas, required TextStyle style, required double maxValue, required double minValue, required int fixedLength, required Rect chartRect}) → void
override
formatNumber(double value, int precision) → String
inherited
getMaxMinValue(KLineEntity entity, double minV, double maxV) → (double, double)
record.$1 : min value record.$2: max value
override
getTextStyle(Color? color) → TextStyle
text format
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited