IndicatorStyle class

Implementers

Constructors

IndicatorStyle({double lineWidth = 1.0, double strokeWidth = 0.8})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
lineWidth → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strokeWidth → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited