MACDStyle class

Inheritance

Constructors

MACDStyle({Color upColor = const Color(0xFF14AD8F), Color dnColor = const Color(0xFFD5405D), Color macdColor = const Color(0xFFFFC634), Color difColor = const Color(0xff35cdac), Color deaColor = const Color(0xffb48ee3), double macdWidth = 8.5})
const

Properties

deaColor → Color
final
difColor → Color
final
dnColor → Color
final
hashCode → int
The hash code for this object.
no setterinherited
lineWidth → double
finalinherited
macdColor → Color
final
macdWidth → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strokeWidth → double
finalinherited
upColor → Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited