RSIStyle class

Inheritance

Constructors

RSIStyle({Color rsiColor = const Color(0xFFFFC634)})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
lineWidth → double
finalinherited
rsiColor → Color
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strokeWidth → double
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited