KChartWidget class

Inheritance

Constructors

KChartWidget(List<KLineEntity>? datas, KChartStyle chartStyle, KChartColors chartColors, {required WidgetDetailBuilder detailBuilder, required bool isTrendLine, double xFrontPadding = 100, List<MainIndicator> mainIndicators = const [], List<SecondaryIndicator> secondaryIndicators = const [], bool volHidden = false, bool isLine = false, bool isTapShowInfoDialog = false, bool hideGrid = false, bool showNowPrice = true, bool showInfoDialog = true, bool materialInfoDialog = true, List<String> timeFormat = TimeFormat.YEAR_MONTH_DAY, dynamic onLoadMore(bool)?, int fixedLength = 2, int flingTime = 600, double flingRatio = 0.5, Curve flingCurve = Curves.decelerate, dynamic isOnDrag(bool)?, VerticalTextAlignment verticalTextAlignment = VerticalTextAlignment.right, double mBaseHeight = 360, double? mSecondaryHeight})

Properties

chartColors → KChartColors
final
chartStyle → KChartStyle
final
datas → List<KLineEntity>?
final
detailBuilder → WidgetDetailBuilder
final
fixedLength → int
final
flingCurve → Curve
final
flingRatio → double
final
flingTime → int
final
hashCode → int
The hash code for this object.
no setterinherited
hideGrid → bool
final
isLine → bool
SecondaryState { MACD, KDJ, RSI, WR, CCI }
final
isOnDrag → dynamic Function(bool)?
final
isTapShowInfoDialog → bool
final
isTrendLine → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mainIndicators → List<MainIndicator>
final
materialInfoDialog → bool
final
mBaseHeight → double
final
mSecondaryHeight → double?
final
onLoadMore → dynamic Function(bool)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryIndicators → List<SecondaryIndicator>
final
showInfoDialog → bool
final
showNowPrice → bool
final
timeFormat → List<String>
final
verticalTextAlignment → VerticalTextAlignment
final
volHidden → bool
warning only using MA, BOLL, SAR
final
xFrontPadding → double
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _KChartWidgetState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited