DepthChartStyle class

Constructors

DepthChartStyle({double lineWidth = 1.0, double radius = 4.0, double strokeWidth = 0.6, double space = 2.0, double padding = 6.0, double dotRadius = 5.0, double crossWidth = 0.5})
const

Properties

crossWidth → double
final
dotRadius → double
final
hashCode → int
The hash code for this object.
no setterinherited
lineWidth → double
final
padding → double
final
radius → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
space → double
final
strokeWidth → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited