KChartStyle class

Constructors

KChartStyle([List<String>? dateTimeFormat])
const

Properties

borderWidth → double
Border width : apply for cross & now price
final
bottomPadding → double
final
candleLineWidth → double
final
candleWidth → double
candle width
final
childPadding → double
final
crossWidth → double
vertical-horizontal cross line width
final
dateTimeFormat → List<String>?
customize the time below
final
gridColumns → int
final
gridRows → int
final
hashCode → int
The hash code for this object.
no setterinherited
nowPriceLineWidth → double
(line length - space line - thickness) of the current price
final
pointWidth → double
point-to-point distance
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
space → double
final
topPadding → double
final
volWidth → double
vol column width
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited