DataUtil class

Constructors

DataUtil()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

calculateAll(List<KLineEntity> dataList, List<MainIndicator> mainLi, List<SecondaryIndicator> secondaryLi) → dynamic
calculateIndicator(List<KLineEntity> dataList, IndicatorTemplate indicator) → dynamic
calculateIndicators(List<KLineEntity> dataList, List<MainIndicator> mainLi, List<SecondaryIndicator> secondaryLi) → dynamic
calcVolumeMA(List<KLineEntity> dataList) → void