NumberUtil class

Constructors

NumberUtil()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

checkNotNullOrZero(double? a) → bool
format(dynamic value, int precision, [String pattern = '#,##0']) → String?
formatCompact(double n, [int precision = 2]) → String
formatFixed(dynamic value, int precision, [String pattern = '#,##0']) → String?