DepthChartColors class
Constructors
- DepthChartColors({Color upColor = const Color(0xFF14AD8F), Color upFillPathColor = const Color(0x2314AD8F), Color dnColor = const Color(0xFFD5405D), Color dnFillPathColor = const Color(0x23D5405D), Color selectBorderColor = const Color(0xFF909196), Color selectFillColor = const Color(0xFFFFFFFF), Color defaultTextColor = const Color(0xFF909196), Color annotationColor = const Color(0xFF222223), Color crossColor = const Color(0xFF191919), Color barrierColor = const Color(0x21AFAFAF)})
-
constructor chart color
const
Properties
- annotationColor → Color
-
color of annotation content
final
- barrierColor → Color
-
barrier color
final
- crossColor → Color
-
color of cross dash line
final
- defaultTextColor → Color
-
default text color: apply for text at grid
final
- dnColor → Color
-
final
- dnFillPathColor → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectBorderColor → Color
-
value border color after selection
final
- selectFillColor → Color
-
background color when value selected
final
- upColor → Color
-
depth color
final
- upFillPathColor → Color
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited