KChartColors class
KChartColors
Note: If you need to apply multi theme, you need to change at least the colors related to the text, border and background color Ex: Background: bgColor, selectFillColor Border Text
Constructors
-
KChartColors({Color bgColor = const Color(0xffffffff), Color kLineColor = const Color(0xff217AFF), List<
Color> kLineFillColors = const [Color(0x80217aff), Color(0x00217AFF)], Color ma5Color = const Color(0xFFFFC634), Color ma10Color = const Color(0xff35cdac), Color upColor = const Color(0xFF14AD8F), Color dnColor = const Color(0xFFD5405D), Color volColor = const Color(0xff2f8fd5), Color volUpColor = const Color(0xFF14AD8F), Color volDnColor = const Color(0xFFD5405D), Color defaultTextColor = const Color(0xFF909196), Color nowPriceUpColor = const Color(0xFF14AD8F), Color nowPriceDnColor = const Color(0xFFD5405D), Color trendLineColor = const Color(0xFFF89215), Color selectBorderColor = const Color(0xFF222223), Color selectFillColor = const Color(0xffffffff), Color gridColor = const Color(0xFFD1D3DB), Color crossColor = const Color(0xFF191919), Color crossTextColor = const Color(0xFF222223), Color maxColor = const Color(0xFF222223), Color minColor = const Color(0xFF222223)}) -
constructor chart color
const
Properties
- bgColor → Color
-
the background color of base chart
final
- crossColor → Color
-
color of the horizontal & vertical cross line
final
- crossTextColor → Color
-
text color
final
- defaultTextColor → Color
-
default text color: apply for text at grid
final
- dnColor → Color
-
final
- gridColor → Color
-
color of grid
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kLineColor → Color
-
Line chart
final
-
kLineFillColors
→ List<
Color> -
final
- ma10Color → Color
-
final
- ma5Color → Color
-
final
- maxColor → Color
-
The color of the maximum and minimum values in the current display
final
- minColor → Color
-
final
- nowPriceDnColor → Color
-
final
- nowPriceUpColor → Color
-
color of the current price
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectBorderColor → Color
-
value border color after selection
final
- selectFillColor → Color
-
background color when value selected
final
- trendLineColor → Color
-
trend color
final
- upColor → Color
-
final
- volColor → Color
-
final
- volDnColor → Color
-
final
- volUpColor → Color
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited